@@ -1,8 +1,13 @@
 from django.contrib import admin, messages
-from django.db.models import F
+from django.db.models import F, DecimalField
 from django.db.models.functions import Coalesce
 from django.utils.safestring import mark_safe
-from django.utils.translation import ugettext_lazy as _
+try:
+    # older Django
+    from django.utils.translation import ugettext_lazy as _
+except ImportError:
+    # Django >= 3
+    from django.utils.translation import gettext_lazy as _
 
 from invoicing.managers import get_accounting_software_manager
 from invoicing.models import Invoice, Item
@@ -42,7 +47,7 @@ class OverdueFilter(admin.SimpleListFilter):
 class InvoiceAdmin(admin.ModelAdmin):
     date_hierarchy = 'date_issue'
     ordering = ['-date_issue', '-sequence']
-    actions = ['send_to_accounting_software', 'export']
+    actions = ['send_to_accounting_software', 'export', 'export_to_pdf']
     list_display = ['pk', 'type', 'number', 'status',
                     'supplier_info', 'customer_info',
                     'annotated_subtotal', 'vat', 'total',
@@ -67,7 +72,7 @@ class InvoiceAdmin(admin.ModelAdmin):
         }),
         (_(u'Payment details'), {
             'fields': (
-                'currency', 'credit', #'already_paid',
+                'currency', 'credit', 'already_paid',
                 ('payment_method', 'delivery_method'),
                 ('constant_symbol', 'variable_symbol', 'specific_symbol', 'reference'),
                 'bank_name', 'bank_country', 'bank_city', 'bank_street', 'bank_zip', 'bank_iban', 'bank_swift_bic'
@@ -94,7 +99,7 @@ class InvoiceAdmin(admin.ModelAdmin):
     )
 
     def get_queryset(self, request):
-        return self.model.objects.annotate(annotated_subtotal=F('total')-Coalesce(F('vat'), 0))
+        return self.model.objects.annotate(annotated_subtotal=F('total')-Coalesce(F('vat'), 0, output_field=DecimalField()))
 
     def annotated_subtotal(self, invoice):
         return invoice.annotated_subtotal
@@ -160,9 +165,29 @@ class InvoiceAdmin(admin.ModelAdmin):
             recipients=[request.user],
             selected_fields=None
         )
+
+        # set queryset
         exporter.queryset = queryset
 
         # export to file
         return exporter.export_to_response()
 
     export.short_description = _('Export to xlsx')
+
+    def export_to_pdf(self, request, queryset):
+        from invoicing.exporters import InvoicePdfDetailExporter
+
+        # init exporter
+        exporter = InvoicePdfDetailExporter(
+            user=request.user,
+            recipients=[request.user],
+            selected_fields=None
+        )
+
+        # set queryset
+        exporter.queryset = queryset
+
+        # export to file
+        return exporter.export_to_response()
+
+    export_to_pdf.short_description = _('Export to PDF')
