@@ -5,7 +5,14 @@ from django.utils import translation
 from django.utils.module_loading import import_string
 from django.utils.safestring import mark_safe
 from django_filters.constants import EMPTY_VALUES
-from django.utils.translation import ugettext_lazy as _
+
+try:
+    # older Django
+    from django.utils.translation import ugettext_lazy as _
+except ImportError:
+    # Django >= 3
+    from django.utils.translation import gettext_lazy as _
+
 from invoicing import settings as invoicing_settings
 from invoicing.models import Invoice
 
