@@ -12,6 +12,7 @@ from model_utils import Choices
 from model_utils.fields import MonitorField
 
 from django.conf import settings
+from invoicing import settings as invoicing_settings
 from django.core.validators import EMPTY_VALUES, MaxValueValidator, MinValueValidator
 from django.db import models, transaction
 from django.db.models import Max, Sum
@@ -25,12 +26,17 @@ except ImportError:
 
 from django.urls import reverse
 from django.utils.timezone import now
-from django.utils.translation import ugettext_lazy as _
+
+try:
+    # older Django
+    from django.utils.translation import ugettext_lazy as _
+except ImportError:
+    # Django >= 3
+    from django.utils.translation import gettext_lazy as _
 
 from invoicing.querysets import InvoiceQuerySet, ItemQuerySet
 from invoicing.taxation import TaxationPolicy
 from invoicing.taxation.eu import EUTaxationPolicy
-from invoicing.utils import import_name
 
 
 def default_supplier(attribute_lookup):
@@ -125,7 +131,7 @@ class Invoice(models.Model):
     subtitle = models.CharField(_(u'subtitle'), max_length=255, blank=True)
     related_document = models.CharField(_(u'related document'), max_length=100, blank=True)
     related_invoices = models.ManyToManyField(to='self', verbose_name=_(u'related invoices'), blank=True)
-    language = models.CharField(_(u'language'), max_length=10, choices=settings.LANGUAGES)
+    language = models.CharField(_(u'language'), max_length=10, choices=invoicing_settings.LANGUAGES)
     note = models.CharField(_(u'note'), max_length=255, blank=True, default=_(u'Thank you for using our services.'))
     date_issue = models.DateField(_(u'issue date'))
     date_tax_point = models.DateField(_(u'tax point date'), help_text=_(u'time of supply'))
@@ -140,7 +146,7 @@ class Invoice(models.Model):
     # Payment details
     currency = models.CharField(_(u'currency'), max_length=10, choices=CURRENCY_CHOICES)
     credit = models.DecimalField(_(u'credit'), max_digits=10, decimal_places=2, default=0)
-    #already_paid = models.DecimalField(_(u'already paid'), max_digits=10, decimal_places=2, default=0)
+    already_paid = models.DecimalField(_(u'already paid'), max_digits=10, decimal_places=2, default=0)
 
     payment_method = models.CharField(_(u'payment method'), choices=PAYMENT_METHOD, max_length=64)
     constant_symbol = models.CharField(_(u'constant symbol'), max_length=64, choices=CONSTANT_SYMBOL, blank=True)
@@ -158,7 +164,7 @@ class Invoice(models.Model):
     bank_city = models.CharField(_(u'bank city'), max_length=255, blank=True)
     bank_country = CountryField(_(u'bank country'), max_length=255, blank=True)
     bank_iban = IBANField(verbose_name=_(u'Account number (IBAN)'), default=None)
-    bank_swift_bic = SWIFTBICField(verbose_name=_(u'Bank SWIFT / BIC'), default=None)
+    bank_swift_bic = SWIFTBICField(verbose_name=_(u'Bank SWIFT / BIC'), blank=True)
 
     # Supplier details
     supplier_name = models.CharField(_(u'supplier name'), max_length=255, default=None)
@@ -293,7 +299,7 @@ class Invoice(models.Model):
         taxation_policy = getattr(settings, 'INVOICING_TAXATION_POLICY', None)
 
         if taxation_policy is not None:
-            return import_name(taxation_policy)
+            return import_string(taxation_policy)
 
         # Check if supplier is from EU
         if self.supplier_country:
@@ -456,6 +462,10 @@ class Invoice(models.Model):
     def total_without_discount(self):
         return Decimal(self.total) + self.discount
 
+    @property
+    def to_pay(self):
+        return self.total - self.already_paid
+
     def calculate_vat(self):
         if len(self.vat_summary) == 1 and self.vat_summary[0]['vat'] is None:
             return None
@@ -474,7 +484,6 @@ class Invoice(models.Model):
 
         #total *= Decimal((100 - Decimal(self.discount)) / 100)  # subtract discount amount
         total -= Decimal(self.credit)  # subtract credit
-        #total -= self.already_paid  # subtract already paid
         return round(total, 2)
 
     def create_copy(self, **kwargs):
